# chibi-redeem

โมดูล Python สำหรับดักซองอั่งเปา TrueMoney ผ่านเบอร์โทร

## วิธีใช้

```python
from chibi import chibi-store-wallet

result = redeem("https://gift.truemoney.com/campaign/?v=XXXXXX", "0987654321")
print(result)
```
